@@ -12,9 +12,9 @@
 INPUT="../../data/multi.grib2"
 
 # Without multi-field support
-c=`${examples_dir}/eccodes_f_grib_count_messages_multi 0 $INPUT | tr -d ' '`
+c=`${examples_dir}/f_grib_count_messages_multi 0 $INPUT | tr -d ' '`
 [ "$c" = "30" ]
 
 # With multi-field support (more messages should be counted)
-c=`${examples_dir}/eccodes_f_grib_count_messages_multi 1 $INPUT | tr -d ' '`
+c=`${examples_dir}/f_grib_count_messages_multi 1 $INPUT | tr -d ' '`
 [ "$c" = "56" ]
