@@ -9,27 +9,25 @@
 # nor does it submit to any jurisdiction.
 #
 
-from __future__ import print_function
-import traceback
 import sys
+import traceback
 
 from eccodes import *
 
-INPUT = '../../data/reduced_gaussian_lsm.grib1'
+INPUT = "../../data/reduced_gaussian_lsm.grib1"
 VERBOSE = 1  # verbose error reporting
 
 
 def example():
     points = ((30, -20), (13, 234))
 
-    f = open(INPUT, 'rb')
+    f = open(INPUT, "rb")
     gid = codes_grib_new_from_file(f)
 
     for lat, lon in points:
         nearest = codes_grib_find_nearest(gid, lat, lon)[0]
         print(lat, lon)
-        print(nearest.lat, nearest.lon, nearest.value, nearest.distance,
-              nearest.index)
+        print(nearest.lat, nearest.lon, nearest.value, nearest.distance, nearest.index)
 
         four = codes_grib_find_nearest(gid, lat, lon, is_lsm=False, npoints=4)
         for i in range(len(four)):
@@ -49,7 +47,7 @@ def main():
         if VERBOSE:
             traceback.print_exc(file=sys.stderr)
         else:
-            sys.stderr.write(err.msg + '\n')
+            sys.stderr.write(err.msg + "\n")
 
         return 1
 
