@@ -20,6 +20,7 @@
     #include "eckit/geo/Grid.h"
     #include "eckit/geo/Exceptions.h"
 
+    #include "geo/GribFromSpec.h"
     #include "geo/GribToSpec.h"
     #include "geo/EckitMainInit.h"
 #endif
@@ -42,19 +43,52 @@ long GridSpec::get_native_type()
     return GRIB_TYPE_STRING;
 }
 
-static void print_warning_feature_not_implemented()
+void GridSpec::print_warning_feature_not_implemented()
 {
-    fprintf(stderr, "ECCODES WARNING :  Key gridSpec is not yet implemented. Work in progress...\n");
+    if (!warned_) {
+        fprintf(stderr, "ECCODES WARNING :  Key gridSpec is not yet implemented. Work in progress...\n");
+        warned_ = true;
+    }
 }
 
-int GridSpec::pack_string(const char* sval, size_t* len)
+int GridSpec::pack_string(const char* v, size_t* len)
 {
-    print_warning_feature_not_implemented();
-    return GRIB_NOT_IMPLEMENTED;
-
 #if defined(HAVE_GEOGRAPHY) && defined(HAVE_ECKIT_GEO)
-    // TODO(mapm)
+    if (context_->eckit_geo == 0) {  // check env. variable too
+        return GRIB_NOT_IMPLEMENTED;
+    }
+
+    ECCODES_ASSERT(len != nullptr && 0 < *len);
+    ECCODES_ASSERT(v != nullptr && v[*len] == '\0');
+
+    std::string spec_str(v);
+    ECCODES_ASSERT(spec_str.length() == *len);
+
+    auto* h = get_enclosing_handle();
+    ECCODES_ASSERT(h != nullptr);
+
+    try {
+        eccodes::geo::eckit_main_init();
+
+        std::unique_ptr<const eckit::geo::Grid> grid(eckit::geo::GridFactory::make_from_string(spec_str));
+        ASSERT(grid);
+
+        auto* result = eccodes::geo::GribFromSpec::set(h, grid->spec());
+        //ECCODES_ASSERT(result != nullptr);
+        if (!result) return GRIB_GEOCALCULUS_PROBLEM;
+    }
+    catch (eckit::geo::Exception& e) {
+        grib_context_log(context_, GRIB_LOG_ERROR, "GridSpec: geo::Exception thrown (%s)", e.what());
+        return GRIB_GEOCALCULUS_PROBLEM;
+    }
+    catch (std::exception& e) {
+        grib_context_log(context_, GRIB_LOG_ERROR, "GridSpec: Exception thrown (%s)", e.what());
+        return GRIB_GEOCALCULUS_PROBLEM;
+    }
+
+    return GRIB_SUCCESS;
 #else
+    print_warning_feature_not_implemented();
     return GRIB_NOT_IMPLEMENTED;
 #endif
 }
@@ -62,7 +96,7 @@ int GridSpec::pack_string(const char* sval, size_t* len)
 int GridSpec::unpack_string(char* v, size_t* len)
 {
 #if defined(HAVE_GEOGRAPHY) && defined(HAVE_ECKIT_GEO)
-    if (context_->eckit_geo == 0) { // check env. variable too
+    if (context_->eckit_geo == 0) {  // check env. variable too
         return GRIB_NOT_IMPLEMENTED;
     }
     ECCODES_ASSERT(0 < *len);
@@ -77,7 +111,10 @@ int GridSpec::unpack_string(char* v, size_t* len)
         eccodes::geo::eckit_main_init();
 
         std::unique_ptr<const eckit::geo::Spec> spec(new eccodes::geo::GribToSpec(h));
+        ASSERT(spec);
+
         std::unique_ptr<const eckit::geo::Grid> grid(eckit::geo::GridFactory::build(*spec));
+        ASSERT(grid);
 
         spec_str = grid->spec_str();
     }
