@@ -25,7 +25,7 @@ SetMissing::SetMissing(grib_context* context, const char* name)
     context_    = context;
     name2_      = grib_context_strdup_persistent(context, name);
 
-    char buf[1024];
+    char buf[1024] = {0,};
     snprintf(buf, sizeof(buf), "set_missing_%s", name);
 
     name_ = grib_context_strdup_persistent(context, buf);
