@@ -9,8 +9,12 @@
 #
 
 . ./include.ctest.sh
-set -u
-REDIRECT=/dev/null
+
+# ---------------------------------------------------------------------
+# This is the test for JIRA issue ECC-1305
+# BUFR: Invalid code in definitions/bufr/tables/operators.table
+# ---------------------------------------------------------------------
+
 label="bufr_ecc-1305_test"
 temp=temp.$label
 
