@@ -82,6 +82,7 @@ done
 
 
 # Test for dumping a section
+# ---------------------------
 if [ $HAVE_JPEG -eq 0 ]; then
     # No JPEG decoding enabled so dumping section 7 will issue errors
     # but dumping non-data sections should work
@@ -110,6 +111,37 @@ ${tools_dir}/grib_dump -w count=4 $file > $temp 2>&1
 file=$data_dir/sample.grib2
 ECCODES_DEBUG=1 ${tools_dir}/grib_dump $file > $temp 2>&1
 
+# Check the right number of sections are listed in the dump
+# ---------------------------------------------------------
+file=$data_dir/sample.grib2
+${tools_dir}/grib_dump -O $file > $temp
+count=$(grep -c SECTION_ $temp)
+[ $count -eq 8 ]
+
+file=$data_dir/test_uuid.grib2
+${tools_dir}/grib_dump -wcount=1 -O $file > $temp
+count=$(grep -c SECTION_ $temp)
+[ $count -eq 7 ]
+
+file=$data_dir/regular_gaussian_model_level.grib1
+${tools_dir}/grib_dump -O $file > $temp
+count=$(grep -c SECTION_ $temp)
+[ $count -eq 4 ]
+
+file=$data_dir/missing_field.grib1
+${tools_dir}/grib_dump -O $file > $temp
+count=$(grep -c SECTION_ $temp)
+[ $count -eq 5 ]
+
+# Repeated key numberOfSection
+file=$data_dir/sample.grib2
+${tools_dir}/grib_dump -O $file > $temp
+grep -q "numberOfSection = 1" $temp
+grep -q "numberOfSection = 3" $temp
+grep -q "numberOfSection = 4" $temp
+grep -q "numberOfSection = 5" $temp
+grep -q "numberOfSection = 7" $temp
+
 
 # Dump long array
 # ----------------
@@ -123,6 +155,13 @@ file=$data_dir/sst_globus0083.grib
 ${tools_dir}/grib_dump -O $file > $temp 2>&1
 grep -q "12-10227752 codedValues" $temp
 
+# Code tables and code flags
+#-----------------------------------------------------------
+file=$data_dir/sample.grib2
+${tools_dir}/grib_dump -Ot $file > $temp 2>&1
+fgrep -q "codetable (int) typeOfFirstFixedSurface = 103 [Specified height level above ground (m)  (grib2/tables/4/4.5.table) ]" $temp
+fgrep -q "codeflag (int) resolutionAndComponentFlags = 48 [00110000 (grib2/tables/4/3.3.table) ]" $temp
+fgrep -q "codeflag (int) scanningMode = 0 [00000000 (grib2/tables/4/3.4.table) ]" $temp
 
 # Error conditions
 #-----------------------------------------------------------
@@ -130,6 +169,13 @@ file=$data_dir/sample.grib2
 ${tools_dir}/grib_dump -p nonexist $file > $temp 2>&1
 grep -q "Key/value not found" $temp
 
+# Invalid options
+set +e
+${tools_dir}/grib_dump -jOD $file > $temp 2>&1
+status=$?
+set -e
+[ $status -ne 0 ]
+
 
 # Unreadable message
 #-----------------------------------------------------------
