@@ -8,7 +8,7 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 
 TEMP=output.grib_local_MeteoFrance.grib
 $EXEC ${test_dir}/grib_local_MeteoFrance $TEMP
